@@ -1,6 +1,10 @@
 from nonebot import on_command
-from nonebot.adapters.cqhttp import Bot, Event
-from nonebot.permission import GROUP_ADMIN, SUPERUSER, GROUP_OWNER
+from nonebot.adapters.cqhttp import Bot, Event, GroupDecreaseNoticeEvent
+from nonebot.permission import SUPERUSER
+from nonebot.adapters.cqhttp.permission import GROUP_ADMIN, GROUP_OWNER
+from nonebot.plugin import on_notice
+
+from .bilireq import BiliReq
 from .config import Config
 from .utils import permission_check, to_me
 from .version import __version__
@@ -194,7 +198,7 @@ async def _(bot: Bot, event: Event, state: dict):
     message = "DD机目前支持的功能有：\n\n"
     for name in func_list:
         message += name
-        if not name.endswith(('列表', '权限')):
+        if not name.endswith(('列表', '权限', '版本信息')):
             message += " uid"
         message += '\n'
     message += "\n命令中的uid需要替换为对应主播的uid，注意是uid不是直播间id\n" + \
@@ -202,4 +206,33 @@ async def _(bot: Bot, event: Event, state: dict):
         "\n所有群聊/私聊的推送都是分开的，在哪里添加就会在哪里推送"
     await help.finish(message)
 
+
+group_decrease = on_notice(priority=5)
+
+@group_decrease.handle()
+async def _(bot: Bot, event: GroupDecreaseNoticeEvent, state: dict):
+    if event.self_id == event.user_id:
+        event.message_type = 'group'
+        c = Config(event)
+        await c.delete_push_list()
+
+
+friend_decrease = on_notice(priority=5)
+
+@group_decrease.handle()
+async def _(bot: Bot, event: GroupDecreaseNoticeEvent, state: dict):
+    if event.self_id == event.user_id:
+        event.message_type = 'group'
+        c = Config(event)
+        await c.delete_push_list()
+
+
+# login = on_command('测试登录', rule=to_me(), permission=SUPERUSER, 
+#     priority=5)
+
+# @login.handle()
+# async def _(bot: Bot, event: Event, state: dict):
+#     b = BiliReq()
+#     await login.send(f"[CQ:image,file=base64://{await b.get_qr()}]")
+#     await login.send(str(await b.qr_login()))
     
\ No newline at end of file
